package com.example.tdl.web;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.example.tdl.domain.dto.CommFeedback;
import com.example.tdl.domain.vo.*;
import com.example.tdl.service.*;
import com.example.tdl.service.redis.RealRedisService;
import com.example.tdl.service.redis.RedisService;
import com.google.gson.Gson;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.influxdb.dto.Query;
import org.influxdb.dto.QueryResult;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import org.springframework.data.influxdb.InfluxDBTemplate;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
public class DataController {
    private Logger logger = LoggerFactory.getLogger(DataController.class);

    Gson gson = new Gson();

    CommFeedback fb = new CommFeedback();

    @Autowired
    private GatewayService gatewayService;

    @Autowired
    private TDLDeviceService tdlDeviceService;

    @Autowired
    private ProbesService probesService;

    @Autowired
    private RealRedisService realRedisService;

    @Autowired
    private InfluxDBTemplate influxDBTemplate;

    @Autowired
    private AlarmLogService alarmLogService;

    @Autowired
    private CircuitService circuitService;

    private final static String database ="original";

    //获取实时数据
    @ApiOperation(value = "获取实时数据",notes = "获取实时数据")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    @PostMapping("/getRealTimeData")
    public Object getRealTimeData(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        //获取gateway的信息
        ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
        if(gatewayVo==null){
            fb.setCode(0);
            fb.setMessage("该线路未绑定设备");
            return gson.toJson(fb);
        }
        //获取tdl信息
        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        //根据gateWay获取tdl信息
        List<String> key = new ArrayList<>();
        key.add(gatewayVo.getSN()+"_"+gatewayVo.getType() +":"+gatewayVo.getSN()+"_"+gatewayVo.getType());
        for (int i = 0;i<devList.size();i++){
            key.add(gatewayVo.getSN()+"_"+gatewayVo.getType()+":"+devList.get(i));
        }
        List<LiveDataVo> liveDataVos = new ArrayList<>();
        for(int j=0;j<key.size();j++){
            Map<Object,Object> ret = realRedisService.getHashAll(key.get(j));
            if(ret == null){
                continue;
            }else{
                Iterator entries = ret.entrySet().iterator();
                List<String> aliasList = new ArrayList<>();
                List<String> valueList = new ArrayList<>();
                while(entries.hasNext()){
                    Map.Entry entry = (Map.Entry) entries.next();
                    aliasList.add((String) entry.getKey());
                    valueList.add((String) entry.getValue());
                }
                //根据通道别名获取通道信息
                List<ProbesVo> probesVoList =  probesService.getByAliasList(gatewayVo.getSN(),gatewayVo.getType(),aliasList);
                for(int m = 0;m<probesVoList.size();m++){
                    probesVoList.get(m).setValue(valueList.get(m));
                }
                LiveDataVo liveDataVo = new LiveDataVo();
                liveDataVo.setKey(key.get(j).substring(key.get(j).indexOf(":"),key.get(j).length()));
                liveDataVo.setProbesVoList(probesVoList);
                liveDataVos.add(liveDataVo);
            }
        }
        return  gson.toJson(liveDataVos);
    }


    //获取坐标数据数据
    @ApiOperation(value = "获取坐标数据数据",notes = "获取坐标数据数据" +
            "time:时间" +
            "lng：经度" +
            "lat: 纬度")
    @PostMapping("/getLocation")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getLocation(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        //获取gateway的信息
        ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
        if(gatewayVo==null){
            fb.setCode(0);
            fb.setMessage("该线路未绑定设备");
            return gson.toJson(fb);
        }
        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
        //获取tdl信息
        // List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        String sql = "SELECT \"lng\",\"lat\" FROM \"tdl_policy\".\""+device+"\"ORDER BY time ";
        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
        //解析经纬度数据
        List<LocationDataVo>  locationDataVos = new ArrayList<>();
        if(queryResult.getResults().get(0).getSeries() != null){
            locationDataVos=getLocation(queryResult);
        }
        return gson.toJson(locationDataVos);
    }


    //根据运输编号获取路线以及设备信息
    @PostMapping("/getCircuit")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object  getCircuit(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        ResultCircuit resultCircuit = new ResultCircuit();
        resultCircuit.setTransportationNo(transportationNo);
        //根据运输编号获取线路信息，设备信息
        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(transportationNo);
        resultCircuit.setStartCity(resultCircuitVo.getStartCity());
        resultCircuit.setStartTime(resultCircuitVo.getStartTime());
        resultCircuit.setEndCity(resultCircuitVo.getEndCity());
        if(StringUtils.isEmpty(resultCircuitVo.getEndTime())){
            resultCircuit.setEndTime("");
            resultCircuit.setLastTime("");
        }else{
            resultCircuit.setEndTime(resultCircuitVo.getEndTime());
            //int i = differentDaysByMillisecond(Long.valueOf(resultCircuitVo.getStartTime()),Long.valueOf(resultCircuitVo.getEndTime())) +1;
            resultCircuit.setLastTime(3+"days");
        }
        //获取gateway的信息
        ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
        if(gatewayVo==null){
            fb.setCode(0);
            fb.setMessage("该线路未绑定设备");
            return gson.toJson(fb);
        }
        resultCircuit.setGatewaySN(gatewayVo.getSN());
        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
        String sql = "SELECT \"battery\"  FROM \"tdl_policy\".\""+device+"\" ORDER BY time  desc limit 1";
        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
        if(queryResult.getResults().get(0).getSeries() != null){
            List<List<Object>> values = getValues(queryResult);
            for(List<Object> value:values){
                logger.info(value.get(1).toString());
                resultCircuit.setBattery(value.get(1)==null ?  "": value.get(1).toString());
            }
        }
        //获取tdl信息
        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        String key=gatewayVo.getSN()+"_"+gatewayVo.getType() +":"+gatewayVo.getSN()+"_"+gatewayVo.getType() ;
        //获取网关以及TDL的电量
        if(devList.size() == 0 ){
            fb.setCode(0);
            fb.setMessage("该线路未绑定设备");
            return gson.toJson(fb);
        }
        for(int i = 0;i<devList.size();i++){
            String sql2 = "SELECT \"b\"  FROM \"tdl_policy\".\""+device+"\" where \"tdl\"=\'tdl-"+devList.get(i)+"\' ORDER BY time desc limit 1";
            QueryResult  queryResult2  = influxDBTemplate.query(new Query(sql2,database));
            if(queryResult2.getResults().get(0).getSeries() != null){
                List<List<Object>> values = getValues(queryResult2);
                for(List<Object> value:values){
                    resultCircuit.setTDLSN(devList.get(i));
                    resultCircuit.setBatteryVoltage(value.get(1)==null ? "" :value.get(1).toString());
                }
            }
        }
        return  gson.toJson(resultCircuit);
    }


    //获取温度数据
    @ApiOperation(value = "获取温度数据",notes = "获取温度数据")
    @PostMapping("/getTemperature")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getTemperature(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
        //获取tdl信息
        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        String devcie=gatewayVo.getType()+"_"+gatewayVo.getSN() ;
        //SELECT "h" FROM "tdl_policy"."WTD93LG_20180314" WHERE "tdl" = 'tdl-0A0B0C0D0F' ORDER BY time DESC
        if(devList.size() == 0){
            fb.setCode(0);
            fb.setMessage("没有数据");
            return gson.toJson(fb);
        }
        List<Temperature> temperatures = new ArrayList<>();
        for( int i =0;i<devList.size();i++){
            Temperature temperature = new Temperature();
            temperature.setTDLSN(devList.get(i));
            String sql = "SELECT \"t\"  FROM \"tdl_policy\".\""+devcie+"\" where \"tdl\"=\'"+devList.get(i)+"\' ORDER BY time ";
            QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
            List<TemperatureDataVo>  temperatureDataVos = new ArrayList<>();
            if(queryResult.getResults().get(0).getSeries() != null){
                //解析数据
                temperatureDataVos = getTemperature(queryResult);
            }
            temperature.setTemperatureDataVos(temperatureDataVos);
            temperatures.add(temperature);
        }
        /*String sql = "SELECT \"t\"  FROM \"tdl_policy\".\""+devcie+"\" ORDER BY time ";
        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
        List<TemperatureDataVo>  temperatureDataVos = new ArrayList<>();
        if(queryResult.getResults().get(0).getSeries() != null){
            //解析数据
            temperatureDataVos = getTemperature(queryResult);
        }*/
        return  gson.toJson(temperatures);
    }


    //获取湿度数据
    @ApiOperation(value = "获取湿度数据",notes = "获取湿度数据")
    @PostMapping("/getHumidity")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getHumidity(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
        //获取tdl信息
        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        String devcie=gatewayVo.getType()+"_"+gatewayVo.getSN() ;
        if(devList.size() == 0){
            fb.setCode(0);
            fb.setMessage("没有数据");
            return gson.toJson(fb);
        }
        List<Humidity> humidities = new ArrayList<>();
        for( int i =0;i<devList.size();i++){
            Humidity humidity = new Humidity();
            humidity.setTDLSN(devList.get(i));
            String sql = "SELECT \"h\"  FROM \"tdl_policy\".\""+devcie+"\" where \"tdl\"=\'"+devList.get(i)+"\' ORDER BY time ";
            QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
            List<HumidityDataVo>  humidityDataVos = new ArrayList<>();
            if(queryResult.getResults().get(0).getSeries() != null){
                //解析数据
                humidityDataVos = getHumidity(queryResult);
            }
            humidity.setHumidityDataVoList(humidityDataVos);
            humidities.add(humidity);
        }
//        //SELECT "h" FROM "tdl_policy"."WTD93LG_20180314" WHERE "tdl" = 'tdl-0A0B0C0D0F' ORDER BY time DESC
//        String sql = "SELECT \"h\"  FROM \"tdl_policy\".\""+devcie+"\" ORDER BY time ";
//        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
//        List<HumidityDataVo>  humidityDataVos = new ArrayList<>();
//        if(queryResult.getResults().get(0).getSeries() != null){
//            //解析数据
//            humidityDataVos = getHumidity(queryResult);
//        }
        return  gson.toJson(humidities);
    }

    //获取倾斜度数据
    @ApiOperation(value = "获取倾斜度数据",notes = "获取倾斜度数据")
    @PostMapping("/getTiltAngle")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getTiltAngle(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
        //获取tdl信息
        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        String devcie=gatewayVo.getType()+"_"+gatewayVo.getSN() ;
        if(devList.size() == 0){
            fb.setCode(0);
            fb.setMessage("没有数据");
            return gson.toJson(fb);
        }
        List<TiltAngle> tiltAngles = new ArrayList<>();
        for( int i =0;i<devList.size();i++){
            TiltAngle tiltAngle = new TiltAngle();
            tiltAngle.setTDLSN(devList.get(i));
            String sql = "SELECT \"ta\"  FROM \"tdl_policy\".\""+devcie+"\" where \"tdl\"=\'"+devList.get(i)+"\' ORDER BY time ";
            QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
            List<TiltAngleVo>  tiltAngleVos = new ArrayList<>();
            if(queryResult.getResults().get(0).getSeries() != null){
                //解析数据
                tiltAngleVos = getTiltAngle(queryResult);
            }
            tiltAngle.setShockEnergyVoList(tiltAngleVos);
            tiltAngles.add(tiltAngle);
        }
//        String sql = "SELECT \"ta\"  FROM \"tdl_policy\".\""+devcie+"\" ORDER BY time ";
//        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
//        List<TiltAngleVo>  tiltAngleVos = new ArrayList<>();
//        if(queryResult.getResults().get(0).getSeries() != null){
//            //解析数据
//            tiltAngleVos = getTiltAngle(queryResult);
//        }
        return  gson.toJson(tiltAngles);
    }

    //获取震动能量
    @ApiOperation(value = "获取震动能量",notes = "获取震动能量")
    @PostMapping("/getShockEnergy")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getShockEnergy(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
        //获取tdl信息
        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        String devcie=gatewayVo.getType()+"_"+gatewayVo.getSN() ;
        if(devList.size() == 0){
            fb.setCode(0);
            fb.setMessage("没有数据");
            return gson.toJson(fb);
        }
        List<ShockEnergy> shockEnergies = new ArrayList<>();
        for( int i =0;i<devList.size();i++){
            ShockEnergy shockEnergy = new ShockEnergy();
            shockEnergy.setTDLSN(devList.get(i));
            String sql = "SELECT \"a0\"  FROM \"tdl_policy\".\""+devcie+"\" where \"tdl\"=\'"+devList.get(i)+"\' ORDER BY time ";
            QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
            List<ShockEnergyVo>  shockEnergyVos = new ArrayList<>();
            if(queryResult.getResults().get(0).getSeries() != null){
                //解析数据
                shockEnergyVos = getShockEnergy(queryResult);
            }
            shockEnergy.setShockEnergyVoList(shockEnergyVos);
            shockEnergies.add(shockEnergy);
        }
//        String sql = "SELECT \"a0\"  FROM \"tdl_policy\".\""+devcie+"\" ORDER BY time ";
//        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
//        List<ShockEnergyVo>  shockEnergyVos = new ArrayList<>();
//        if(queryResult.getResults().get(0).getSeries() != null){
//            //解析数据
//            shockEnergyVos = getShockEnergy(queryResult);
//        }
        return  gson.toJson(shockEnergies);
    }



    //根据运输编号获取所有的报警数据
    @ApiOperation(value = "根据运输编号获取所有的报警数据????",notes = "根据运输编号获取所有的报警数据")
    @PostMapping("/getAlarmData")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public  Object  getAlarmData(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        //根据运输编号获取报警信息
        List<AlarmLogVo> alarmLogVoList = alarmLogService.getByTransportationNo(transportationNo);

        return  gson.toJson(alarmLogVoList);
    }


    //根据时间获取经纬度信息
    @ApiOperation(value = "获取震动能量",notes = "获取震动能量")
    @PostMapping("/getLocationByTime")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getLocationByTime(@RequestBody LocationVo locationVo ){
        //获取线路信息
        //获取网关以及tdl信息
        ResultGatewayVo gatewayVo = circuitService.getByNo(locationVo.getTransportationNo());
        ResultCircuitVo resultCircuitVo = circuitService.getByTransportationNo(locationVo.getTransportationNo());
        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
        //获取tdl信息
        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        String devcie=gatewayVo.getType()+"_"+gatewayVo.getSN() ;
        //根据时间获取坐标信息
        String sql ="SELECT \"lng\",\"lat\" FROM \"tdl_policy\".\""+devcie+"\" where time = "+locationVo.getTime() *1000000l;
        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
        List<LocationMessageVo>  locationDataVos = new ArrayList<>();
        if(queryResult.getResults().get(0).getSeries() != null){
            List<List<Object>> values = getValues(queryResult);
            for(List<Object> value:values){
                LocationMessageVo messageVo = new LocationMessageVo();
                messageVo.setTransportationNo(locationVo.getTransportationNo());
                messageVo.setGatewaySN(gatewayVo.getSN());
                messageVo.setTDLSN(devList);
                messageVo.setStartCity(resultCircuitVo.getStartCity());
                messageVo.setEndCity(resultCircuitVo.getEndCity());
                messageVo.setStartTime(resultCircuitVo.getStartTime());
                messageVo.setEndTime(resultCircuitVo.getEndTime());
                messageVo.setAlarmTime(Long.valueOf(parseTime(value.get(0).toString())));
                messageVo.setAlarmType(locationVo.getAlarmType());
                messageVo.setAlarmValue(locationVo.getVlaue());
                messageVo.setLng(value.get(1)==null ?  "": value.get(1).toString());
                messageVo.setLat(value.get(2)==null ?  "" :value.get(2).toString());
                locationDataVos.add(messageVo);
            }
        }
        return  gson.toJson(locationDataVos);
    }


    //获取温度、湿度、震动强度、震动能量、倾斜度
    @PostMapping("/getDeviceData")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType="header", name = "Account_token", value = "token", required = true, dataType = "String"),
    })
    public Object getDeviceData(@RequestBody String transportationNo){
        JSONObject jsonObject= JSON.parseObject(transportationNo);
        transportationNo=jsonObject.getString("transportationNo");
        //获取网关以及tdl信息
        ResultGatewayVo gatewayVo = circuitService.getByNo(transportationNo);
        String device = gatewayVo.getType() +"_" +gatewayVo.getSN();
        //获取tdl信息
        List<String> devList = tdlDeviceService.getByGatewaySN(gatewayVo.getSN(),gatewayVo.getType());
        String devcie=gatewayVo.getType()+"_"+gatewayVo.getSN() ;
        //SELECT "h" FROM "tdl_policy"."WTD93LG_20180314" WHERE "tdl" = 'tdl-0A0B0C0D0F' ORDER BY time DESC
        String sql = "SELECT \"t\",\"h\",\"p\",\"a0\",\"ta\" FROM \"tdl_policy\".\""+devcie+"\" where \"tdl\" = \'"+devList.get(0)+"\' ORDER BY time ";
        QueryResult  queryResult  = influxDBTemplate.query(new Query(sql,database));
        //解析经纬度数据
        List<DeviceDataVo>  deviceDataVos = new ArrayList<>();
        if(queryResult.getResults().get(0).getSeries() != null){
            deviceDataVos= getDeviceData(queryResult);
        }
        return gson.toJson(deviceDataVos);
    }

    //解析数据
    public List<LocationDataVo> getLocation(QueryResult  queryResult){
        List<List<Object>> values = getValues(queryResult);
        List<LocationDataVo> historyDataList = new ArrayList<>();
        for(List<Object> value:values){
            LocationDataVo historyData = new LocationDataVo();
            historyData.setTime(parseTime(value.get(0).toString()));
            historyData.setLng(Double.parseDouble(value.get(1).toString()));
            historyData.setLat(Double.parseDouble(value.get(2).toString()));
            historyData.setError(0);//没有预警
            historyDataList.add(historyData);
        }
        return historyDataList;
    }

    public List<DeviceDataVo> getDeviceData(QueryResult  queryResult){
        List<List<Object>> values = getValues(queryResult);
        List<DeviceDataVo> historyDataList = new ArrayList<>();
        for(List<Object> value:values){
            DeviceDataVo historyData = new DeviceDataVo();
            historyData.setTime(parseTime(value.get(0).toString()));
            historyData.setTemperature(value.get(1)==null ? "" :value.get(1).toString());
            historyData.setHumidity(value.get(2)==null  ? "" :value.get(2).toString());
            historyData.setPressure(value.get(3)==null  ? "" :value.get(3).toString());
            historyData.setShockEnergy(value.get(4)==null  ? "" :value.get(4).toString());
            historyData.setTiltAngle(value.get(5)==null  ? "" :value.get(5).toString());
            historyDataList.add(historyData);
        }
        return historyDataList;
    }

    public List<TemperatureDataVo> getTemperature(QueryResult  queryResult){
        List<List<Object>> values = getValues(queryResult);
        List<TemperatureDataVo> historyDataList = new ArrayList<>();
        for(List<Object> value:values){
            TemperatureDataVo historyData = new TemperatureDataVo();
            historyData.setTime(parseTime(value.get(0).toString()));
            historyData.setValue(value.get(1)==null  ? "" :value.get(1).toString());
            historyDataList.add(historyData);
        }
        return historyDataList;
    }

    public List<TiltAngleVo> getTiltAngle(QueryResult  queryResult){
        List<List<Object>> values = getValues(queryResult);
        List<TiltAngleVo> historyDataList = new ArrayList<>();
        for(List<Object> value:values){
            TiltAngleVo historyData = new TiltAngleVo();
            historyData.setTime(parseTime(value.get(0).toString()));
            historyData.setValue(value.get(1)==null  ? "" :value.get(1).toString());
            historyDataList.add(historyData);
        }
        return historyDataList;
    }

    public List<ShockEnergyVo> getShockEnergy(QueryResult  queryResult){
        List<List<Object>> values = getValues(queryResult);
        List<ShockEnergyVo> historyDataList = new ArrayList<>();
        for(List<Object> value:values){
            ShockEnergyVo historyData = new ShockEnergyVo();
            historyData.setTime(parseTime(value.get(0).toString()));
            historyData.setValue(value.get(1)==null  ? "" :value.get(1).toString());
            historyDataList.add(historyData);
        }
        return historyDataList;
    }

    public List<HumidityDataVo> getHumidity(QueryResult  queryResult){
        List<List<Object>> values = getValues(queryResult);
        List<HumidityDataVo> historyDataList = new ArrayList<>();
        for(List<Object> value:values){
            HumidityDataVo historyData = new HumidityDataVo();
            historyData.setTime(parseTime(value.get(0).toString()));
            historyData.setValue(value.get(1)==null  ? "" :value.get(1).toString());
            historyDataList.add(historyData);
        }
        return historyDataList;
    }

    //解析数据格式
    public List<List<Object>>  getValues( QueryResult  queryResult){
        List<List<Object>> values = new ArrayList<>();
        for(QueryResult.Result result : queryResult.getResults()){
            if(result.getSeries() !=null){
                for (QueryResult.Series series : result.getSeries()) {
                    if(series !=null){
                        values= series.getValues();
                    }
                }
            }
        }
        return values;
    }

    //将utc时间转换成时间戳
    public static String dateToStamp(String s) throws ParseException {
        Date date =null ;
        if(s.length() !=20 ) {
            date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'").parse(s);
        }else{
            date = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'").parse(s);
        }
        return String.valueOf(date.getTime());
    }

    //解析时间
    public String parseTime(String time){
        String dateResult =null;
        try {
            dateResult = dateToStamp(time);
        } catch (Exception e) {
            e.printStackTrace();
            logger.info(e.toString());
            fb.setCode(0);
            fb.setMessage("解析时间异常");
        }
        return dateResult;
    }

    //判断两个时间相差多少
    public static int differentDaysByMillisecond(Long date1,Long date2){
        int days = (int) ((date2-date1) / (1000*3600*24)) ;
        return days;
    }



}